package net.knarcraft.placeholdersigns.container;

import org.bukkit.Location;
import org.bukkit.configuration.serialization.ConfigurationSerializable;
import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.Map;

/**
 * A sign containing one or more placeholders
 *
 * @param location     <p>The location of the sign</p>
 * @param placeholders <p>The original placeholders typed on the sign</p>
 */
public record PlaceholderSign(Location location,
                              Map<Integer, String> placeholders) implements ConfigurationSerializable {

    @Override
    @NotNull
    public Map<String, Object> serialize() {
        Map<String, Object> data = new HashMap<>();
        data.put("location", location);
        data.put("placeholders", placeholders);
        return data;
    }

    /**
     * Deserializes the placeholder-sign specified in the given data
     *
     * @param data <p>The data to deserialize</p>
     * @return <p>The deserialized placeholder sign</p>
     */
    @SuppressWarnings({"unchecked", "unused"})
    public static PlaceholderSign deserialize(Map<String, Object> data) {
        return new PlaceholderSign((Location) data.get("location"), (Map<Integer, String>) data.get("placeholders"));
    }

}
